@@ -32,10 +32,12 @@
 #include <string.h>
 #include <errno.h>
 #include <math.h>
+#include <stdlib.h>
 
 #include "pref.h"
 
 #include "image-view.h"
+#include "image-list.h"
 #include "working-area.h"
 #include "ptk-menu.h"
 #include "jpeg-tran.h"
@@ -174,7 +176,7 @@ void main_win_init( MainWin*mw )
     vadj->page_increment = 10;
     gtk_adjustment_changed(vadj);
 
-    image_view_set_adjustments( mw->img_view, hadj, vadj );    // dirty hack :-(
+    image_view_set_adjustments( IMAGE_VIEW(mw->img_view), hadj, vadj );    // dirty hack :-(
     gtk_scrolled_window_add_with_viewport( (GtkScrolledWindow*)mw->scroll, mw->evt_box );
     GtkWidget* viewport = gtk_bin_get_child( (GtkBin*)mw->scroll );
     gtk_viewport_set_shadow_type( (GtkViewport*)viewport, GTK_SHADOW_NONE );
@@ -900,13 +902,20 @@ gboolean on_button_release( GtkWidget* widget, GdkEventButton* evt, MainWin* mw
 
 gboolean on_scroll_event( GtkWidget* widget, GdkEventScroll* evt, MainWin* mw )
 {
+    guint modifiers = gtk_accelerator_get_default_mod_mask();
     switch( evt->direction )
     {
     case GDK_SCROLL_UP:
-        on_zoom_out( NULL, mw );
+        if ((evt->state & modifiers) == GDK_CONTROL_MASK)
+            on_zoom_in( NULL, mw );
+        else
+            on_prev( NULL, mw );
         break;
     case GDK_SCROLL_DOWN:
-        on_zoom_in( NULL, mw );
+        if ((evt->state & modifiers) == GDK_CONTROL_MASK)
+            on_zoom_out( NULL, mw );
+        else
+            on_next( NULL, mw );
         break;
     case GDK_SCROLL_LEFT:
         on_prev( NULL, mw );
@@ -1025,7 +1034,7 @@ void rotate_image( MainWin* mw, GdkPixbufRotation angle )
     rpix = gdk_pixbuf_rotate_simple( mw->pix, angle );
     g_object_unref( mw->pix );
     mw->pix = rpix;
-    image_view_set_pixbuf( mw->img_view, mw->pix );
+    image_view_set_pixbuf( (ImageView*)mw->img_view, mw->pix );
 
     if( mw->zoom_mode == ZOOM_FIT )
         main_win_fit_window_size( mw, FALSE, GDK_INTERP_BILINEAR );
@@ -1039,7 +1048,7 @@ gboolean main_win_scale_image( MainWin* mw, double new_scale, GdkInterpType type
         return TRUE;
     }
     mw->scale = new_scale;
-    image_view_set_scale( mw->img_view, new_scale, type );
+    image_view_set_scale( (ImageView*)mw->img_view, new_scale, type );
 
     return TRUE;
 }
@@ -1163,7 +1172,6 @@ void on_about( GtkWidget* menu, MainWin* mw )
         "洪任諭 Hong Jen Yee <pcman.tw@gmail.com>",
         "Martin Siggel <martinsiggel@googlemail.com>",
         _(" * Refer to source code of EOG image viewer and GThumb"),
-        _(" * Some icons are taken from gimmage"),
         NULL
     };
     /* TRANSLATORS: Replace mw string with your names, one name per line. */
